==> intel-media-driver_23.1.1+dfsg1.orig.tar.xz: media-driver-intel-media-23.1.1/media_softlet/agnostic/common/codec/hal/enc/av1/packet/media_srcs.cmake <==
# Copyright (c) 2022, Intel Corporation
#
# Permission is hereby granted, free of charge, to any person obtaining a
# copy of this software and associated documentation files (the "Software"),
# to deal in the Software without restriction, including without limitation
# the rights to use, copy, modify, merge, publish, distribute, sublicense,
# and/or sell copies of the Software, and to permit persons to whom the
# Software is furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included
# in all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
# OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
# THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR
# OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE,
# ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
# OTHER DEALINGS IN THE SOFTWARE.

if ("${AV1_Encode_VDEnc_Supported}" STREQUAL "yes")
set(TMP_SOURCES_
    ${CMAKE_CURRENT_LIST_DIR}/encode_av1_vdenc_packet.cpp
    ${CMAKE_CURRENT_LIST_DIR}/encode_back_annotation_packet.cpp
    ${CMAKE_CURRENT_LIST_DIR}/encode_av1_brc_init_packet.cpp
    ${CMAKE_CURRENT_LIST_DIR}/encode_av1_brc_update_packet.cpp
)

set(TMP_HEADERS_
    ${CMAKE_CURRENT_LIST_DIR}/encode_av1_vdenc_packet.h
    ${CMAKE_CURRENT_LIST_DIR}/encode_back_annotation_packet.h
    ${CMAKE_CURRENT_LIST_DIR}/encode_av1_brc_init_packet.h
    ${CMAKE_CURRENT_LIST_DIR}/encode_av1_brc_update_packet.h
)

set(SOFTLET_ENCODE_AV1_HEADERS_
    ${SOFTLET_ENCODE_AV1_HEADERS_}
    ${TMP_HEADERS_}
)

set(SOFTLET_ENCODE_AV1_SOURCES_
    ${SOFTLET_ENCODE_AV1_SOURCES_}
    ${TMP_SOURCES_}
)

source_group( CodecHalNext\\Shared\\Encode FILES ${TMP_SOURCES_} ${TMP_HEADERS_} )

set(TMP_SOURCES_ "")
set(TMP_HEADERS_ "")

endif()

set(SOFTLET_ENCODE_AV1_PRIVATE_INCLUDE_DIRS_
    ${SOFTLET_ENCODE_AV1_PRIVATE_INCLUDE_DIRS_}
    ${CMAKE_CURRENT_LIST_DIR}
)

==> intel-media-driver_25.3.4+dfsg1.orig.tar.xz: media-driver-intel-media-25.3.4/media_softlet/agnostic/common/codec/hal/enc/av1/packet/media_srcs.cmake <==
# Copyright (c) 2022-2023, Intel Corporation
#
# Permission is hereby granted, free of charge, to any person obtaining a
# copy of this software and associated documentation files (the "Software"),
# to deal in the Software without restriction, including without limitation
# the rights to use, copy, modify, merge, publish, distribute, sublicense,
# and/or sell copies of the Software, and to permit persons to whom the
# Software is furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included
# in all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
# OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
# THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR
# OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE,
# ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
# OTHER DEALINGS IN THE SOFTWARE.

if ("${AV1_Encode_VDEnc_Supported}" STREQUAL "yes")
set(TMP_SOURCES_
    ${CMAKE_CURRENT_LIST_DIR}/encode_av1_vdenc_packet.cpp
    ${CMAKE_CURRENT_LIST_DIR}/encode_back_annotation_packet.cpp
    ${CMAKE_CURRENT_LIST_DIR}/encode_av1_brc_init_packet.cpp
    ${CMAKE_CURRENT_LIST_DIR}/encode_av1_brc_update_packet.cpp
    ${CMAKE_CURRENT_LIST_DIR}/encode_av1_pak_integrate_packet.cpp
)

set(TMP_HEADERS_
    ${CMAKE_CURRENT_LIST_DIR}/encode_av1_vdenc_packet.h
    ${CMAKE_CURRENT_LIST_DIR}/encode_back_annotation_packet.h
    ${CMAKE_CURRENT_LIST_DIR}/encode_av1_brc_init_packet.h
    ${CMAKE_CURRENT_LIST_DIR}/encode_av1_brc_update_packet.h
    ${CMAKE_CURRENT_LIST_DIR}/encode_av1_pak_integrate_packet.h
)

set(SOFTLET_ENCODE_AV1_HEADERS_
    ${SOFTLET_ENCODE_AV1_HEADERS_}
    ${TMP_HEADERS_}
)

set(SOFTLET_ENCODE_AV1_SOURCES_
    ${SOFTLET_ENCODE_AV1_SOURCES_}
    ${TMP_SOURCES_}
)

source_group( CodecHalNext\\Shared\\Encode FILES ${TMP_SOURCES_} ${TMP_HEADERS_} )

set(TMP_SOURCES_ "")
set(TMP_HEADERS_ "")

endif()

set(SOFTLET_ENCODE_AV1_PRIVATE_INCLUDE_DIRS_
    ${SOFTLET_ENCODE_AV1_PRIVATE_INCLUDE_DIRS_}
    ${CMAKE_CURRENT_LIST_DIR}
)
